(this.webpackJsonpstreamlit_tags=this.webpackJsonpstreamlit_tags||[]).push([[0],{17:function(e,t,a){e.exports=a(28)},26:function(e,t,a){},28:function(e,t,a){"use strict";a.r(t);var r=a(2),n=a.n(r),i=a(11),o=a.n(i),l=a(3),c=a(9),s=a(1),u=a(7);function d(){for(var e=arguments.length,t=new Array(e),a=0;a<e;a++)t[a]=arguments[a];return t.join(" ")}var b=Object(u.a)({alignItems:"center",background:"var(--rti-tag)",borderRadius:"var(--rti-radius)",display:"inline-flex",justifyContent:"center",paddingLeft:"var(--rti-s)",button:{background:"none",border:0,borderRadius:"50%",cursor:"pointer",lineHeight:"inherit",padding:"0 var(--rti-s)","&:hover":{color:"var(--rti-tag-remove)"}}});function g(e){var t=e.text,a=e.remove;return n.a.createElement("span",{className:d("rti--tag",b)},n.a.createElement("span",null,t),n.a.createElement("button",{type:"button",onClick:function(e){e.stopPropagation(),a(t)},"aria-label":"remove ".concat(t)},"\u2715"))}var m=a(13);Object(u.b)(n.a.createElement);var v=Object(u.a)({"--rtiBg":"#fff","--rtiBorder":"#ccc","--rtiMain":"#3182ce","--rtiRadius":"0.375rem","--rtiS":"0.5rem","--rtiTag":"#edf2f7","--rtiTagRemove":"#e53e3e","*":{boxSizing:"border-box",transition:"all 0.2s ease"},alignItems:"center",bg:"var(--rti-bg)",border:"1px solid var(--rti-border)",borderRadius:"var(--rti-radius)",display:"flex",flexWrap:"wrap",gap:"var(--rti-s)",lineHeight:1.4,padding:"var(--rti-s)","&:focus-within":{borderColor:"var(--rti-main)",boxShadow:"var(--rti-main) 0px 0px 0px 1px"}}),p=Object(u.a)({border:0,outline:0,fontSize:"inherit",lineHeight:"inherit",width:"100%"}),f=["Enter"],h=function(e){var t=e.name,a=e.placeHolder,i=e.value,o=e.onChange,c=e.onBlur,u=e.seprators,b=e.onExisting,h=e.onRemoved,E=e.suggestions,x=Object(r.useState)(i||[]),j=Object(l.a)(x,2),y=j[0],O=j[1];Object(r.useEffect)((function(){o&&o(y)}),[y]);var w=function(e){O(y.filter((function(t){return t!==e}))),h&&h(e)};return n.a.createElement("div",{"aria-labelledby":t,className:d("rti--container",v)},y.map((function(e){return n.a.createElement(g,{key:e,text:e,remove:w})})),n.a.createElement(m.Hint,{options:E,allowTabFill:!0},n.a.createElement("input",{className:d("rti--input",p),type:"text",name:t,placeholder:a,onKeyDown:function(e){e.stopPropagation();var t=e.target.value;if("Backspace"===e.key&&y.length&&!t&&O(y.slice(0,-1)),t&&(u||f).includes(e.key)){if(y.includes(t))return void(b&&b(t));O([].concat(Object(s.a)(y),[t])),e.target.value="",e.preventDefault()}},onBlur:c})))},E=(a(26),Object(c.b)((function(e){var t=e.args,a=t.label,i=t.text,o=t.initialValue,s=t.suggestions,u=Object(r.useState)(o),d=Object(l.a)(u,2),b=d[0],g=d[1];return Object(r.useEffect)((function(){return c.a.setFrameHeight()})),n.a.createElement("div",null,n.a.createElement(h,{value:b,onChange:function(e){return g(t=e),void c.a.setComponentValue(t);var t},name:a,placeHolder:i,suggestions:s}))}))),x=a(15),j=a(16),y=a(33),O=a(29),w=new x.a;o.a.render(n.a.createElement(n.a.StrictMode,null,n.a.createElement(j.a,{value:w},n.a.createElement(y.a,{theme:O.a},n.a.createElement(E,null)))),document.getElementById("root"))}},[[17,1,2]]]);
//# sourceMappingURL=main.572f56c1.chunk.js.map